@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2018-2021 Arnaud Rebillout
+ * Copyright (C) 2018-2024 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-only
  *
@@ -22,11 +22,27 @@
 
 #include <gio/gio.h>
 
-gboolean gv_in_test_suite(void);
+/* URI utils */
 
-GSettings *gv_get_settings(const gchar *component);
+extern const gchar *GV_SUPPORTED_URI_SCHEMES[];
+extern const gchar *GV_SUPPORTED_MIME_TYPES[];
+
+gboolean gv_is_uri_scheme_supported    (const gchar *uri);
+gboolean gv_get_uri_extension_lowercase(const gchar *uri, gchar **extension, GError **err);
+
+/* XDG utils */
 
 const gchar *gv_get_app_user_config_dir(void);
 const gchar *gv_get_app_user_data_dir(void);
 const gchar *const *gv_get_app_system_config_dirs(void);
 const gchar *const *gv_get_app_system_data_dirs(void);
+
+/* TLS utils */
+
+gchar *gv_tls_errors_to_string(GTlsCertificateFlags errors);
+
+/* Misc utils */
+
+GSettings *gv_get_settings(const gchar *component);
+
+gboolean gv_in_test_suite(void);
