@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2021 Arnaud Rebillout
+ * Copyright (C) 2015-2024 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-only
  *
@@ -39,6 +39,7 @@ static const gchar *translators =
 	"Michal Čihař <michal@cihar.com> - Czech (cs)\n"
 	"Torben Grove <torben_grove@live.dk> - Danish (da)\n"
 	"Andreas Kleinert <Andy.Kleinert@gmail.com> - German (de)\n"
+	"Ettore Atalan <atalanttore@googlemail.com> - German (de)\n"
 	"Vinz <vinz@vinzv.de> - German (de)\n"
 	"Daniel Bageac <danielbageac@gmail.com> - English (United States) (en_US)\n"
 	"Adolfo Jayme Barrientos <fitojb@ubuntu.com> - Spanish (es)\n"
@@ -51,6 +52,7 @@ static const gchar *translators =
 	"Notramo <notramo@vipmail.hu> -  (hu)\n"
 	"Reza Almanda <rezaalmanda27@gmail.com> - Indonesian (id)\n"
 	"Silvyaamalia <silvyaamalia@student.uns.ac.id> - Indonesian (id)\n"
+	"Albanobattistella <albano_battistella@hotmail.com> - Italian (it)\n"
 	"Dallenog <dallenog@gmail.com> - Italian (it)\n"
 	"Luca De Filippo <luca.defilippo@translationcommons.org> - Italian (it)\n"
 	"Prachi Joshi <josprachi@yahoo.com> - Marathi (mr)\n"
@@ -59,6 +61,7 @@ static const gchar *translators =
 	"Def Cik <devcik88@gmail.com> - Polish (pl)\n"
 	"Eryk Michalak <gnu.ewm@protonmail.com> - Polish (pl)\n"
 	"Michal Biesiada <blade-14@o2.pl> - Polish (pl)\n"
+	"Zbigniew Rosiek <zrosiek@gmail.com> - Polish (pl)\n"
 	"Fúlvio Alves <fga.fulvio@gmail.com> - Portuguese (Brazil) (pt_BR)\n"
 	"Ssantos <ssantos@web.de> - Portuguese (pt)\n"
 	"Manuela Silva <mmsrs@sky.com> - Portuguese (Portugal) (pt_PT)\n"
