@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2021 Arnaud Rebillout
+ * Copyright (C) 2015-2024 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-only
  *
@@ -87,7 +87,7 @@ make_confirmation_dialog(GtkWindow *parent)
 	GtkStyleContext *style_context;
 
 	dialog = gtk_message_dialog_new(parent,
-					GTK_DIALOG_DESTROY_WITH_PARENT,
+					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 					GTK_MESSAGE_QUESTION,
 					GTK_BUTTONS_NONE,
 					_("Remove all Stations?"));
@@ -103,6 +103,65 @@ make_confirmation_dialog(GtkWindow *parent)
 	return dialog;
 }
 
+static void
+on_add_station_dialog_response(GtkWidget* dialog,
+		gint response_id,
+		GtkWindow *parent G_GNUC_UNUSED)
+{
+	GvStationDialog *station_dialog = GV_STATION_DIALOG(dialog);
+	GvStationList *station_list = gv_core_station_list;
+	GvStation *station = NULL;
+	GvStation *anchor = NULL;
+
+	if (response_id != GTK_RESPONSE_OK)
+		goto out;
+
+	station = gv_station_dialog_create(station_dialog);
+	if (station == NULL)
+		goto out;
+
+	anchor = gv_station_dialog_get_anchor(station_dialog);
+	if (anchor != NULL)
+		gv_station_list_insert_after(station_list, station, anchor);
+	else
+		gv_station_list_append(station_list, station);
+
+out:
+	gtk_widget_destroy(dialog);
+}
+
+static void
+on_edit_station_dialog_response(GtkWidget* dialog,
+		gint response_id,
+		GtkWindow *parent G_GNUC_UNUSED)
+{
+	GvStationDialog *station_dialog = GV_STATION_DIALOG(dialog);
+
+	if (response_id != GTK_RESPONSE_OK)
+		goto out;
+
+	gv_station_dialog_apply(station_dialog);
+
+out:
+	gtk_widget_destroy(dialog);
+}
+
+static void
+on_remove_all_stations_dialog_response(GtkWidget* dialog,
+		gint response_id,
+		GtkWindow *parent G_GNUC_UNUSED)
+{
+	GvStationList *station_list = gv_core_station_list;
+
+	if (response_id != GTK_RESPONSE_ACCEPT)
+		goto out;
+
+	gv_station_list_empty(station_list);
+
+out:
+	gtk_widget_destroy(dialog);
+}
+
 static void
 on_menu_item_activate(GtkMenuItem *item, GvStationContextMenu *self)
 {
@@ -112,18 +171,22 @@ on_menu_item_activate(GtkMenuItem *item, GvStationContextMenu *self)
 	GtkWidget *widget = GTK_WIDGET(item);
 
 	if (widget == priv->add_station_menu_item) {
-		GvStation *station;
+		GtkWindow *parent = GTK_WINDOW(gv_ui_main_window);
+		GtkWidget *dialog;
 
-		station = gv_show_add_station_dialog(GTK_WINDOW(gv_ui_main_window));
-		if (station) {
-			if (selected_station)
-				gv_station_list_insert_after(station_list, station, selected_station);
-			else
-				gv_station_list_append(station_list, station);
-		}
+		dialog = gv_make_add_station_dialog(parent, selected_station);
+		g_signal_connect_object(dialog, "response",
+				G_CALLBACK(on_add_station_dialog_response), parent, 0);
+		gtk_widget_show(dialog);
 
 	} else if (widget == priv->edit_station_menu_item && selected_station) {
-		gv_show_edit_station_dialog(GTK_WINDOW(gv_ui_main_window), selected_station);
+		GtkWindow *parent = GTK_WINDOW(gv_ui_main_window);
+		GtkWidget *dialog;
+
+		dialog = gv_make_edit_station_dialog(parent, selected_station);
+		g_signal_connect_object(dialog, "response",
+				G_CALLBACK(on_edit_station_dialog_response), parent, 0);
+		gtk_widget_show(dialog);
 
 	} else if (widget == priv->remove_station_menu_item && selected_station) {
 		gv_station_list_remove(station_list, selected_station);
@@ -131,15 +194,11 @@ on_menu_item_activate(GtkMenuItem *item, GvStationContextMenu *self)
 	} else if (widget == priv->remove_all_stations_menu_item) {
 		GtkWindow *parent = GTK_WINDOW(gv_ui_main_window);
 		GtkWidget *dialog;
-		int response;
 
 		dialog = make_confirmation_dialog(parent);
-		response = gtk_dialog_run(GTK_DIALOG(dialog));
-		gtk_widget_destroy(dialog);
-
-		if (response == GTK_RESPONSE_ACCEPT)
-			gv_station_list_empty(station_list);
-
+		g_signal_connect_object(dialog, "response",
+			G_CALLBACK(on_remove_all_stations_dialog_response), parent, 0);
+		gtk_widget_show(dialog);
 	} else {
 		CRITICAL("Unhandled menu item %p", item);
 	}
@@ -157,7 +216,7 @@ gv_station_context_menu_populate(GvStationContextMenu *self)
 	GtkWidget *widget;
 
 	/* This is supposed to be called once only */
-	g_assert_null(gtk_container_get_children(GTK_CONTAINER(self)));
+	g_assert(gtk_container_get_children(GTK_CONTAINER(self)) == NULL);
 
 	/* Add station */
 	widget = gtk_menu_item_new_with_label(ADD_STATION_LABEL);
@@ -202,7 +261,7 @@ gv_station_context_menu_set_station(GvStationContextMenu *self, GvStation *stati
 	GvStationContextMenuPrivate *priv = self->priv;
 
 	/* This is a construct-only property - NULL is allowed */
-	g_assert_null(priv->station);
+	g_assert(priv->station == NULL);
 	g_set_object(&priv->station, station);
 }
 
